@@ -11,6 +11,10 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+
+#include <algorithm>
+#include <atomic>
+
 #include "src/post_filter.h"
 #include "src/utils/blocking_counter.h"
 
